@@ -126,6 +126,16 @@ class SettingsDialog(object):
 		for t in xrange( 0, 2400, 100 ):
 			self.store_backup_time.append( [ datetime.time( t/100, t%100 ).strftime("%H:%M"), t ] )
 
+		#automatic backup day store
+		self.store_backup_day = gtk.ListStore( str, int )
+		for t in xrange( 1, 29 ):
+			self.store_backup_day.append( [ str(t), t ] )
+
+		#automatic backup weekday store
+		self.store_backup_weekday = gtk.ListStore( str, int )
+		for t in xrange( 1, 8 ):
+			self.store_backup_weekday.append( [ datetime.date(2011, 11, 6 + t).strftime("%A"), t ] )
+
 		#per directory schedule
 		#self.cb_per_directory_schedule = get( 'cb_per_directory_schedule' )
 		#self.lbl_schedule = get( 'lbl_schedule' )
@@ -194,7 +204,29 @@ class SettingsDialog(object):
 		self.cb_backup_time.pack_start( renderer, True )
 		self.cb_backup_time.add_attribute( renderer, 'text', 0 )
 		
-		self.hbox_backup_time = get( 'hbox_backup_time' )
+		self.lbl_backup_time = get( 'lbl_backup_time' )
+
+		#setup automatic backup day
+		self.cb_backup_day = get( 'cb_backup_day' )
+		self.cb_backup_day.set_model( self.store_backup_day )
+
+		self.cb_backup_day.clear()
+		renderer = gtk.CellRendererText()
+		self.cb_backup_day.pack_start( renderer, True )
+		self.cb_backup_day.add_attribute( renderer, 'text', 0 )
+		
+		self.lbl_backup_day = get( 'lbl_backup_day' )
+
+		#setup automatic backup weekday
+		self.cb_backup_weekday = get( 'cb_backup_weekday' )
+		self.cb_backup_weekday.set_model( self.store_backup_weekday )
+
+		self.cb_backup_weekday.clear()
+		renderer = gtk.CellRendererText()
+		self.cb_backup_weekday.pack_start( renderer, True )
+		self.cb_backup_weekday.add_attribute( renderer, 'text', 0 )
+		
+		self.lbl_backup_weekday = get( 'lbl_backup_weekday' )
 
 		#setup remove old backups older than
 		self.edit_remove_old_backup_value = get( 'edit_remove_old_backup_value' )
@@ -250,8 +282,6 @@ class SettingsDialog(object):
 		self.cb_enable_notifications = get( 'cb_enable_notifications' )
 		self.cb_backup_on_restore = get( 'cb_backup_on_restore' )
 		self.cb_continue_on_errors = get( 'cb_continue_on_errors' )
-		self.cb_use_gloobus_preview = get( 'cb_use_gloobus_preview' )
-		self.cb_use_gloobus_preview.set_active( self.config.get_bool_value( 'gnome.use_gloobus_preview', True ) )
 		self.cb_use_checksum = get( 'cb_use_checksum' )
 
 		#log level
@@ -273,6 +303,7 @@ class SettingsDialog(object):
 		self.cb_run_nice_from_cron = get('cb_run_nice_from_cron')
 		self.cb_run_ionice_from_cron = get('cb_run_ionice_from_cron')
 		self.cb_run_ionice_from_user = get('cb_run_ionice_from_user')
+		
 		self.cb_preserve_acl = get('cb_preserve_acl')
 		self.cb_preserve_xattr = get('cb_preserve_xattr')
 		self.cb_copy_unsafe_links = get('cb_copy_unsafe_links')
@@ -284,6 +315,9 @@ class SettingsDialog(object):
 			self.cb_no_on_battery.set_sensitive( False )
 			self.cb_no_on_battery.set_tooltip_text( 'Power status not available from system' )
 
+		#check for changes
+		self.cb_check_for_changes = get('cb_check_for_changes')
+
 		self.update_profiles()
 	
 	def error_handler( self, message ):
@@ -316,18 +350,31 @@ class SettingsDialog(object):
 
 	def on_cb_backup_mode_changed( self, *params ):
 		iter = self.cb_backup_mode.get_active_iter()
+		if iter is None:
+			return
 
-		hide_time = True
-
-		if not iter is None:
-			backup_mode = self.store_backup_mode.get_value( iter, 1 )
-			if backup_mode >= self.config.DAY:
-				hide_time = False
-
-		if hide_time:
-			self.hbox_backup_time.hide()
+		backup_mode = self.store_backup_mode.get_value( iter, 1 )
+		
+		if backup_mode >= self.config.DAY:
+			self.lbl_backup_time.show()
+			self.cb_backup_time.show()
 		else:
-			self.hbox_backup_time.show()
+			self.lbl_backup_time.hide()
+			self.cb_backup_time.hide()
+
+		if backup_mode == self.config.WEEK:
+			self.lbl_backup_weekday.show()
+			self.cb_backup_weekday.show()
+		else:
+			self.lbl_backup_weekday.hide()
+			self.cb_backup_weekday.hide()
+		
+		if backup_mode == self.config.MONTH:
+			self.lbl_backup_day.show()
+			self.cb_backup_day.show()
+		else:
+			self.lbl_backup_day.hide()
+			self.cb_backup_day.hide()
 
 	def update_host_user_profile( self, *params ):
 		value = not self.cb_auto_host_user_profile.get_active()
@@ -433,6 +480,28 @@ class SettingsDialog(object):
 			iter = self.store_backup_time.iter_next( iter )
 			i = i + 1
 		
+		#setup automatic backup day
+		i = 0
+		iter = self.store_backup_day.get_iter_first()
+		default_mode = self.config.get_automatic_backup_day( self.profile_id )
+		while not iter is None:
+			if self.store_backup_day.get_value( iter, 1 ) == default_mode:
+				self.cb_backup_day.set_active( i )
+				break
+			iter = self.store_backup_day.iter_next( iter )
+			i = i + 1
+		
+		#setup automatic backup weekday
+		i = 0
+		iter = self.store_backup_weekday.get_iter_first()
+		default_mode = self.config.get_automatic_backup_weekday( self.profile_id )
+		while not iter is None:
+			if self.store_backup_weekday.get_value( iter, 1 ) == default_mode:
+				self.cb_backup_weekday.set_active( i )
+				break
+			iter = self.store_backup_weekday.iter_next( iter )
+			i = i + 1
+		
 		self.on_cb_backup_mode_changed()
 
 		#setup remove old backups older than
@@ -514,6 +583,9 @@ class SettingsDialog(object):
 		self.cb_copy_unsafe_links.set_active(self.config.copy_unsafe_links( self.profile_id ))
 		self.cb_copy_links.set_active(self.config.copy_links( self.profile_id ))
 		
+		#check for changes
+		self.cb_check_for_changes.set_active( self.config.check_for_changes( self.profile_id ) )
+	
 	def save_profile( self ):
 		#profile_id = self.config.get_current_profile()
 		#snapshots path
@@ -560,6 +632,8 @@ class SettingsDialog(object):
 		#global schedule
 		self.config.set_automatic_backup_mode( self.store_backup_mode.get_value( self.cb_backup_mode.get_active_iter(), 1 ), self.profile_id )
 		self.config.set_automatic_backup_time( self.store_backup_time.get_value( self.cb_backup_time.get_active_iter(), 1 ), self.profile_id )
+		self.config.set_automatic_backup_day( self.store_backup_day.get_value( self.cb_backup_day.get_active_iter(), 1 ), self.profile_id )
+		self.config.set_automatic_backup_weekday( self.store_backup_weekday.get_value( self.cb_backup_weekday.get_active_iter(), 1 ), self.profile_id )
 		
 		#auto-remove snapshots
 		self.config.set_remove_old_snapshots( 
@@ -586,6 +660,7 @@ class SettingsDialog(object):
 		self.config.set_backup_on_restore( self.cb_backup_on_restore.get_active(), self.profile_id )
 		self.config.set_continue_on_errors( self.cb_continue_on_errors.get_active(), self.profile_id )
 		self.config.set_use_checksum( self.cb_use_checksum.get_active(), self.profile_id )
+		self.config.set_check_for_changes( self.cb_check_for_changes.get_active(), self.profile_id )
 		self.config.set_log_level( self.store_log_level.get_value( self.combo_log_level.get_active_iter(), 0 ), self.profile_id )
 		
 		#expert options
@@ -676,7 +751,7 @@ class SettingsDialog(object):
 		self.update_profiles()
 	
 	def on_remove_profile( self, button ):
-		if gtk.RESPONSE_YES == messagebox.show_question( self.dialog, self.config, _('Are you sure you want to delete the profile "%s" ?') % self.config.get_profile_name() ):
+		if gtk.RESPONSE_YES == messagebox.show_question( self.dialog, self.config, _('Are you sure you want to delete the profile "%s" ?') % self.config.get_profile_name(self.profile_id) ):
 			self.config.remove_profile( self.profile_id )
 			self.profile_id = '1'
 			self.update_profiles()
@@ -785,8 +860,6 @@ class SettingsDialog(object):
 		if not self.config.setup_cron():
 			return False
 		
-		self.config.set_bool_value( 'gnome.use_gloobus_preview', self.cb_use_gloobus_preview.get_active() )
-
 		self.config.save()
 		return True
 	
