@@ -31,6 +31,7 @@ from PyKDE4.kio import *
 import config
 import tools
 import kde4tools
+import restoredialog
 
 
 _=gettext.gettext
@@ -106,14 +107,16 @@ class SnapshotsDialog( KDialog ):
 		self.main_layout.addWidget( self.toolbar )
 
 		#toolbar restore
+		menu_restore = QMenu()
+		action = menu_restore.addAction( KIcon( 'document-revert' ), QString.fromUtf8( _('Restore') ) )
+		QObject.connect( action, SIGNAL('triggered()'), self.restore_this )
+		action = menu_restore.addAction( KIcon( 'document-revert' ), QString.fromUtf8( _('Restore to ...') ) )
+		QObject.connect( action, SIGNAL('triggered()'), self.restore_this_to )
+
 		self.btn_restore = self.toolbar.addAction( KIcon( 'document-revert' ), '' )
 		self.btn_restore.setToolTip( QString.fromUtf8( _('Restore') ) )
-		QObject.connect( self.btn_restore, SIGNAL('triggered()'), self.on_btn_restore_clicked )
-
-		#toolbar copy
-		self.btn_copy = self.toolbar.addAction( KIcon( 'edit-copy' ), '' )
-		self.btn_copy.setToolTip( QString.fromUtf8( _('Copy') ) )
-		QObject.connect( self.btn_copy, SIGNAL('triggered()'), self.on_btn_copy_to_clipboard_clicked )
+		self.btn_restore.setMenu(menu_restore)
+		QObject.connect( self.btn_restore, SIGNAL('triggered()'), self.restore_this )
 
 		#list different snapshots only
 		self.cb_only_different_snapshots = QCheckBox( QString.fromUtf8( _( 'List only different snapshots' ) ), self )
@@ -128,7 +131,7 @@ class SnapshotsDialog( KDialog ):
 		self.list_snapshots = KListWidget( self )
 		self.main_layout.addWidget( self.list_snapshots )
 		QObject.connect( self.list_snapshots, SIGNAL('currentItemChanged(QListWidgetItem*,QListWidgetItem*)'), self.on_list_snapshots_changed )
-		QObject.connect( self.list_snapshots, SIGNAL('executed(QListWidgetItem*)'), self.on_list_snapshots_executed )
+		QObject.connect( self.list_snapshots, SIGNAL('itemActivated(QListWidgetItem*)'), self.on_list_snapshots_executed )
 
 		#diff
 		layout = QHBoxLayout()
@@ -209,21 +212,17 @@ class SnapshotsDialog( KDialog ):
 	def update_toolbar( self ):
 		snapshot_id = self.get_list_snapshot_id()
 
-		self.btn_copy.setEnabled( len( snapshot_id ) > 0 )
 		self.btn_restore.setEnabled( len( snapshot_id ) > 1 )
 
-	def on_btn_restore_clicked( self ):
+	def restore_this( self ):
 		snapshot_id = self.get_list_snapshot_id()
 		if len( snapshot_id ) > 1:
-			self.snapshots.restore( snapshot_id, self.path )
+			restoredialog.restore( self, snapshot_id, self.path )
 
-	def on_btn_copy_to_clipboard_clicked( self ):
+	def restore_this_to( self ):
 		snapshot_id = self.get_list_snapshot_id()
-		if len( snapshot_id ) < 1:
-			return
-
-		path = self.snapshots.get_snapshot_path_to( snapshot_id, self.path )
-		kde4tools.clipboard_set_path( self.kapp, path )
+		if len( snapshot_id ) > 1:
+			restoredialog.restore( self, snapshot_id, self.path, None )
 
 	def on_list_snapshots_changed( self ):
 		self.update_toolbar()
